package
Version:
v0.7.0
Opens a new window with list of versions in this module.
Published: May 25, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Done[V any](yield func(V) bool, done func()) func(V) bool
Done wraps yield and calls done when yield returns false.
func Done2[K, V any](yield func(K, V) bool, done func()) func(K, V) bool
Done2 wraps yield and calls done when yield returns false.
Once wraps yield to ensure each unique value is only yielded once.
Once2 wraps yield to ensure each unique value (but not key) is only yielded once.
TODO: necessary?
Source Files
¶
Click to show internal directories.
Click to hide internal directories.